function hOut = dotplot(x, y, scores, varargin)


% Part of PFCMP version 2.5.41, an extension to the PSIGNIFIT toolbox for MATLAB versions 5 and up.
% The license and NO WARRANTY statement for PSIGNIFIT also applies to this release - see psych_legal.m
% Copyright (c) J.Hill 2002.
% mailto:psignifit@bootstrap-software.org
% http://www.bootstrap-software.org/psignifit/

if nargin < 3, scores = []; end
if nargin < 2, y = []; end
if isstr(y), varargin = [{y scores} varargin]; y = []; scores = []; end
if isstr(scores), varargin = [{scores} varargin]; scores = []; end

if size(x, 2) == 2 & (isempty(y) | isempty(scores))
	if isempty(scores), scores = y; end
	y = x(:, 2);
	x = x(:, 1);
end
if isempty(y), [x y] = deal(y, x); end
if isempty(x), x = 1:length(y); end
x = x(:);
y = y(:);
scores = scores(:);

if length(x) ~= length(y), error('mismatched argument lengths'), end
if ~isempty(scores) & length(scores) ~= length(y), error('mismatched argument lengths'), end

if ~ishold, cla, end

[keys vals err] = keysvals(varargin); error(err)

defaultOpts = {'marker', 'o', 'markersize', 5, 'linestyle', 'none', 'color', [0 0 1]};

scores(isinf(scores)) = nan;
if all(isnan([nan;scores]))
	h = line(x, y, defaultOpts{:}, varargin{:});
else
	if strcmpi(get(gca, 'climmode'), 'auto')
		cr = [min(scores) max(scores)];
	else
		cr = get(gca, 'clim');
	end
	set(gca, 'clim', cr)
	
	scores(scores < cr(1)) = cr(1);
	scores(scores > cr(2)) = cr(2);
	scores(isnan(scores)) = cr(2);
	scores = scores - cr(1);
	if diff(cr) scores = scores / diff(cr); end
		
	m = colormap;
	colours = m(round(1 + scores * (size(m, 1) - 1)), :);
	h = line([x x]', [y y]', defaultOpts{:}, varargin{:});
	set(h, {'xdata', 'ydata', 'color'}, [num2cell(x), num2cell(y) num2cell(colours, 2)])
end
if strcmp(get(h(1), 'marker'), '.')
	ms = get(h, {'markersize'}); ms = cat(1, ms{:});
	set(h, {'markersize'}, num2cell(ms * 3.65))
end
if ~any(strcmp(lower(keys), 'markerfacecolor')) set(h, {'markerfacecolor'}, get(h, {'color'})), end
if nargout, hOut = h; else figure(gcf), drawnow, end
