function setprefs(funcname, varargin)
% SETPREFS(FUNC, pref1name, pref1val, ....)
% 	Record global preferences for function FUNC (adds to existing
% 	preferences - use [] to delete a field).
% SETPREFS(FUNC, P)  % where P is a 1x1 struct
% 	Record global preferences for function FUNC (overwrites
% 	existing preferences - use [] to remove all prefs).
% 
% See also GETPREFS, CLEARPREFS

% Part of PFCMP version 2.5.41, an extension to the PSIGNIFIT toolbox for MATLAB versions 5 and up.
% The license and NO WARRANTY statement for PSIGNIFIT also applies to this release - see psych_legal.m
% Copyright (c) J.Hill 2002.
% mailto:psignifit@bootstrap-software.org
% http://www.bootstrap-software.org/psignifit/

[ans funcname ans] = fileparts(funcname);
prefvarname = ['PREFS_' upper(funcname)];

changed = 0;
eval(['global ' prefvarname])
prefstruct = eval(prefvarname, '[]');
if ~isstruct(prefstruct) | prod(size(prefstruct)) ~= 1
	prefstruct = [];
	changed = 1;
end

if length(varargin) == 1
	arg = varargin{1};
	if isequal(arg, []) | (isstruct(arg) & prod(size(arg)) == 1)
		prefstruct = arg;
		changed = 1;
	else
		error('single prefs argument must be a 1-by-1 struct')
	end
else
	[keys vals err] = keysvals(varargin); error(err)
	keys = lower(keys);
	for i = 1:length(keys)
		if isequal(vals{i}, [])
			if isfield(prefstruct, keys{i})
				prefstruct = rmfield(prefstruct, keys{i});
				changed = 1;
			end
		else
% 			if isequal(vals{i}, '1'), vals{i} = 1; end
% 			if isequal(vals{i}, '0'), vals{i} = 0; end
			if isstr(vals{i})
				[isnum num] = isstrnum(vals{i});
				if isnum, vals{i} = num; end
			end
			prefstruct = setfield(prefstruct, keys{i}, vals{i});
			changed = 1;
		end
	end
end
if changed, eval([prefvarname ' = prefstruct;']), end
if isequal(prefstruct, []), eval(['clear global ' prefvarname]), end
